@@ -28,7 +28,7 @@ from .version import Version
 class AccountFlags:
     def __init__(self, version: Version, initialized: bool, market: bool, open_orders: bool,
                  request_queue: bool, event_queue: bool, bids: bool, asks: bool, disabled: bool) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.version: Version = version
         self.initialized: bool = initialized
         self.market: bool = market
@@ -56,7 +56,7 @@ class AccountFlags:
         flags += ["asks" if self.asks else None]
         flags += ["disabled" if self.disabled else None]
         flag_text = " | ".join(flag for flag in flags if flag is not None) or "None"
-        return f"« 𝙰𝚌𝚌𝚘𝚞𝚗𝚝𝙵𝚕𝚊𝚐𝚜: {flag_text} »"
+        return f"« AccountFlags: {flag_text} »"
 
     def __repr__(self) -> str:
         return f"{self}"
