@@ -39,7 +39,7 @@ from .watcher import Watcher
 #
 class Inventory:
     def __init__(self, inventory_source: InventorySource, liquidity_incentives: InstrumentValue, available_collateral: InstrumentValue, base: InstrumentValue, quote: InstrumentValue) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.inventory_source: InventorySource = inventory_source
         self.available_collateral: InstrumentValue = available_collateral
         self.liquidity_incentives: InstrumentValue = liquidity_incentives
@@ -54,7 +54,7 @@ class Inventory:
         liquidity_incentives: str = ""
         if self.liquidity_incentives.value > 0:
             liquidity_incentives = f" {self.liquidity_incentives}"
-        return f"« 𝙸𝚗𝚟𝚎𝚗𝚝𝚘𝚛𝚢 {self.symbol}{liquidity_incentives} [{self.base} / {self.quote}] ({self.available_collateral} available) »"
+        return f"« Inventory {self.symbol}{liquidity_incentives} [{self.base} / {self.quote}] ({self.available_collateral} available) »"
 
     def __repr__(self) -> str:
         return f"{self}"
