@@ -59,7 +59,7 @@ from .orders import Order, OrderBook
 #
 class MarketInstructionBuilder(metaclass=abc.ABCMeta):
     def __init__(self) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
 
     @abc.abstractmethod
     def build_cancel_order_instructions(self, order: Order, ok_if_missing: bool = False) -> CombinableInstructions:
@@ -106,7 +106,7 @@ class MarketInstructionBuilder(metaclass=abc.ABCMeta):
 #
 class MarketOperations(metaclass=abc.ABCMeta):
     def __init__(self, market: Market) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.market: Market = market
 
     @abc.abstractmethod
@@ -171,7 +171,7 @@ class NullMarketInstructionBuilder(MarketInstructionBuilder):
         return CombinableInstructions.empty()
 
     def __str__(self) -> str:
-        return f"« 𝙽𝚞𝚕𝚕𝙼𝚊𝚛𝚔𝚎𝚝𝙸𝚗𝚜𝚝𝚛𝚞𝚌𝚝𝚒𝚘𝚗𝙱𝚞𝚒𝚕𝚍𝚎𝚛 {self.symbol} »"
+        return f"« NullMarketInstructionBuilder {self.symbol} »"
 
 
 # # 🥭 NullMarketOperations class
@@ -185,11 +185,11 @@ class NullMarketOperations(MarketOperations):
         self.market_name: str = market_name
 
     def cancel_order(self, order: Order, ok_if_missing: bool = False) -> typing.Sequence[str]:
-        self.logger.info(f"[Dry Run] Not cancelling order {order}.")
+        self._logger.info(f"[Dry Run] Not cancelling order {order}.")
         return [""]
 
     def place_order(self, order: Order) -> Order:
-        self.logger.info(f"[Dry Run] Not placing order {order}.")
+        self._logger.info(f"[Dry Run] Not placing order {order}.")
         return order
 
     def load_orderbook(self) -> OrderBook:
@@ -211,4 +211,4 @@ class NullMarketOperations(MarketOperations):
         return SYSTEM_PROGRAM_ADDRESS
 
     def __str__(self) -> str:
-        return f"""« 𝙳𝚛𝚢𝚁𝚞𝚗𝙼𝚊𝚛𝚔𝚎𝚝𝙾𝚙𝚎𝚛𝚊𝚝𝚒𝚘𝚗𝚜 [{self.market_name}] »"""
+        return f"""« NullMarketOperations [{self.market_name}] »"""
